# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instalabel.client.api.images_api import ImagesApi


class TestImagesApi(unittest.TestCase):
    """ImagesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ImagesApi()

    def tearDown(self) -> None:
        pass

    def test_get_image_api_v1_images_image_id_get(self) -> None:
        """Test case for get_image_api_v1_images_image_id_get

        Get Image
        """
        pass

    def test_get_project_images_api_v1_images_get(self) -> None:
        """Test case for get_project_images_api_v1_images_get

        Get Project Images
        """
        pass

    def test_upload_image_api_v1_images_post(self) -> None:
        """Test case for upload_image_api_v1_images_post

        Upload Image
        """
        pass


if __name__ == '__main__':
    unittest.main()
